@@ -293,6 +293,7 @@ class Turbot(discord.Client):
                         "island",
                         "friend",
                         "fruit",
+                        "nickname",
                     ]
                 )
         return self._users_data
@@ -1257,6 +1258,17 @@ class Turbot(discord.Client):
         self.save_user_pref(author, "hemisphere", home)
         return s("hemisphere", name=author), None
 
+    def nickname_command(self, channel, author, params):
+        """
+        Set your nickname, such as your Switch user name. | <name>
+        """
+        if not params:
+            return s("nickname_no_params"), None
+
+        name = " ".join(params)  # allow spaces in nicknames
+        self.save_user_pref(author, "nickname", name)
+        return s("nickname", name=author), None
+
     def timezone_command(self, channel, author, params):
         """
         Set your timezone. You can find a list of supported TZ names at
@@ -1440,6 +1452,10 @@ class Turbot(discord.Client):
                     embed.add_field(name="during", value=info["months"])
                     if info["alert"]:
                         embed.add_field(name="alert", value=info["alert"])
+                        if "GONE" in info["alert"]:
+                            embed.color = discord.Color.orange()
+                        else:
+                            embed.color = discord.Color.blue()
                     response.append(embed)
                 return add_header(response)
 
@@ -1496,18 +1512,9 @@ class Turbot(discord.Client):
         embed = discord.Embed(title=user.name)
         embed.set_thumbnail(url=user.avatar_url)
 
-        island = prefs.get("island", "Not set")
-        embed.add_field(name="Island", value=island)
-
-        hemisphere = prefs.get("hemisphere", "Not set").title()
-        embed.add_field(name="Hemisphere", value=hemisphere)
-
-        now = self.to_usertime(user.id, datetime.now(pytz.UTC))
-        current_time = now.strftime("%I:%M %p %Z")
-        embed.add_field(name="Current time", value=current_time)
-
-        fruit = prefs.get("fruit", "Not set").title()
-        embed.add_field(name="Native fruit", value=fruit)
+        nickname = prefs.get("nickname", None)
+        if nickname:
+            embed.add_field(name="Nickname", value=nickname)
 
         code = prefs.get("friend", None)
         if code:
@@ -1516,6 +1523,19 @@ class Turbot(discord.Client):
         else:
             embed.add_field(name="Friend code", value="Not set")
 
+        island = prefs.get("island", "Not set")
+        embed.add_field(name="Island", value=island)
+
+        hemisphere = prefs.get("hemisphere", "Not set").title()
+        embed.add_field(name="Hemisphere", value=hemisphere)
+
+        fruit = prefs.get("fruit", "Not set").title()
+        embed.add_field(name="Native fruit", value=fruit)
+
+        now = self.to_usertime(user.id, datetime.now(pytz.UTC))
+        current_time = now.strftime("%I:%M %p %Z")
+        embed.set_footer(text=f"Current time is {current_time}")
+
         return embed
 
     def info_command(self, channel, author, params):
@@ -1537,6 +1557,36 @@ class Turbot(discord.Client):
 
         return s("info_not_found"), None
 
+    def about_command(self, channel, author, params):
+        """
+        Get information about Turbot.
+        """
+        embed = discord.Embed(title="Turbot")
+        embed.set_thumbnail(
+            url="https://raw.githubusercontent.com/theastropath/turbot/master/turbot.png"
+        )
+        embed.add_field(
+            name="Version",
+            value=f"[{__version__}](https://pypi.org/project/turbot/{__version__}/)",
+        )
+        embed.add_field(name="Package", value="[PyPI](https://pypi.org/project/turbot/)")
+        embed.add_field(
+            name="Author", value="[TheAstropath](https://github.com/theastropath)"
+        )
+        embed.add_field(
+            name="Maintainer", value="[lexicalunit](https://github.com/lexicaluit)"
+        )
+        embed.description = (
+            "A Discord bot for everything _Animal Crossing: New Horizons._\n"
+            "\n"
+            "Use the command `!help` for usage details. Having issues with Turbot? "
+            "Please [report bugs](https://github.com/theastropath/turbot/issues)!\n"
+        )
+        embed.url = "https://github.com/theastropath/turbot"
+        embed.set_footer(text="MIT © TheAstropath, lexicalunit et al")
+        embed.color = discord.Color(0xFFFDC3)
+        return embed, None
+
 
 def get_token(token_file):  # pragma: no cover
     """Returns the discord token from the environment or your token config file."""
